@@ -20,18 +20,18 @@
 #include <string>
 #include <fcntl.h>
 
-#include <ntqstring.h>
-#include <ntqsplitter.h>
-#include <ntqtimer.h>
-#include <ntqvaluelist.h>
-#include <ntqlayout.h>
-#include <ntqlineedit.h>
-#include <ntqbuffer.h>
-#include <ntqtoolbutton.h>
-#include <ntqtabwidget.h>
-#include <ntqlabel.h>
-#include <ntqtextedit.h>
-#include <ntqclipboard.h>
+#include <tqstring.h>
+#include <tqsplitter.h>
+#include <tqtimer.h>
+#include <tqvaluelist.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqbuffer.h>
+#include <tqtoolbutton.h>
+#include <tqtabwidget.h>
+#include <tqlabel.h>
+#include <tqtextedit.h>
+#include <tqclipboard.h>
 #include <kinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
@@ -59,15 +59,15 @@
 #endif
 
 #include <string.h>
-#include <entry.h>
-#include <documentlistviewitem.h>
-#include <documentlistview.h>
-#include <fileexporter.h>
-#include <fileexporterbibtex.h>
-#include <fileexporterxml.h>
-#include <fileexporterxslt.h>
-#include <settings.h>
-#include <encoderlatex.h>
+#include "entry.h"
+#include "documentlistviewitem.h"
+#include "documentlistview.h"
+#include "fileexporter.h"
+#include "fileexporterbibtex.h"
+#include "fileexporterxml.h"
+#include "fileexporterxslt.h"
+#include "settings.h"
+#include "encoderlatex.h"
 #include "kbibtex_part.h"
 
 const TQString inPipeFilename = TQDir::homeDirPath() + "/.kbibtex.in";
